pub struct ComponentLifecycle { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world component-lifecycle.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
ComponentLifecycle::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
ComponentLifecyclePreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesComponentLifecyclePre::instantiateto create aComponentLifecycle. -
If you’ve instantiated the instance yourself already then you can use
ComponentLifecycle::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl ComponentLifecycle
impl ComponentLifecycle
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ComponentLifecycle, Error>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<ComponentLifecycle, Error>
Convenience wrapper around ComponentLifecyclePre::new and
ComponentLifecyclePre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<ComponentLifecycle, Error>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<ComponentLifecycle, Error>
Convenience wrapper around ComponentLifecycleIndices::new and
ComponentLifecycleIndices::load.
pub fn greentic_lifecycle_lifecycle_v1(&self) -> &Guest