pub struct ComponentLifecycleIndices { /* private fields */ }Expand description
Auto-generated bindings for index of the exports of
component-lifecycle.
This is an implementation detail of ComponentLifecyclePre and can
be constructed if needed as well.
For more information see ComponentLifecycle as well.
Implementations
Sourceimpl ComponentLifecycleIndices
impl ComponentLifecycleIndices
Sourcepub fn new<_T>(
_instance_pre: &InstancePre<_T>,
) -> Result<ComponentLifecycleIndices, Error>
pub fn new<_T>( _instance_pre: &InstancePre<_T>, ) -> Result<ComponentLifecycleIndices, Error>
Creates a new copy of ComponentLifecycleIndices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn load(
&self,
store: impl AsContextMut,
instance: &Instance,
) -> Result<ComponentLifecycle, Error>
pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<ComponentLifecycle, Error>
Uses the indices stored in self to load an instance
of ComponentLifecycle from the instance provided.
Note that at this time this method will additionally perform type-checks of all exports.