pub struct ComponentConfigurable { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world component-configurable.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
ComponentConfigurable::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
ComponentConfigurablePreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesComponentConfigurablePre::instantiateto create aComponentConfigurable. -
If you’ve instantiated the instance yourself already then you can use
ComponentConfigurable::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl ComponentConfigurable
impl ComponentConfigurable
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ComponentConfigurable, Error>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<ComponentConfigurable, Error>
Convenience wrapper around ComponentConfigurablePre::new and
ComponentConfigurablePre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<ComponentConfigurable, Error>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<ComponentConfigurable, Error>
Convenience wrapper around ComponentConfigurableIndices::new and
ComponentConfigurableIndices::load.
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> <D as HasData>::Data<'_>, ) -> Result<(), Error>
pub fn greentic_component_node(&self) -> &Guest
pub fn greentic_component_component_config_schema(&self) -> &Guest