pub struct ComponentHostIndices { /* private fields */ }Expand description
Auto-generated bindings for index of the exports of
component-host.
This is an implementation detail of ComponentHostPre and can
be constructed if needed as well.
For more information see ComponentHost as well.
Implementations
Sourceimpl ComponentHostIndices
impl ComponentHostIndices
Sourcepub fn new<_T>(
_instance_pre: &InstancePre<_T>,
) -> Result<ComponentHostIndices, Error>
pub fn new<_T>( _instance_pre: &InstancePre<_T>, ) -> Result<ComponentHostIndices, Error>
Creates a new copy of ComponentHostIndices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn load(
&self,
store: impl AsContextMut,
instance: &Instance,
) -> Result<ComponentHost, Error>
pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<ComponentHost, Error>
Uses the indices stored in self to load an instance
of ComponentHost from the instance provided.
Note that at this time this method will additionally perform type-checks of all exports.