v1 host capability contracts.
Modules
- greentic
greentic:http/client@1.0.0bindings.- v1_1
greentic:http/client@1.1.0bindings with request options + tenant context.
Structs
- Client
greentic:http/client@1.0.0bindings. Auto-generated bindings for an instance a component which implements the worldclient.- Client
Indices greentic:http/client@1.0.0bindings. Auto-generated bindings for index of the exports ofclient.- Client
Pre greentic:http/client@1.0.0bindings. Auto-generated bindings for a pre-instantiated version of a component which implements the worldclient.
Constants
- PACKAGE_
ID greentic:http/client@1.0.0bindings.