ClientIndices

Struct ClientIndices 

pub struct ClientIndices {}
greentic:http/client@1.0.0 bindings. Auto-generated bindings for index of the exports of client.

This is an implementation detail of ClientPre and can be constructed if needed as well.

For more information see Client as well.

Implementations

Source

impl ClientIndices

pub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<ClientIndices, Error>

Creates a new copy of ClientIndices bindings which can then be used to instantiate into a particular store.

This method may fail if the component does not have the required exports.

pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<Client, Error>

Uses the indices stored in self to load an instance of Client from the instance provided.

Note that at this time this method will additionally perform type-checks of all exports.