pub struct HookProvider { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world hook-provider.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
HookProvider::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
HookProviderPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesHookProviderPre::instantiateto create aHookProvider. -
If you’ve instantiated the instance yourself already then you can use
HookProvider::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl HookProvider
impl HookProvider
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<HookProvider, Error>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<HookProvider, Error>
Convenience wrapper around HookProviderPre::new and
HookProviderPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<HookProvider, Error>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<HookProvider, Error>
Convenience wrapper around HookProviderIndices::new and
HookProviderIndices::load.
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> <D as HasData>::Data<'_>, ) -> Result<(), Error>
pub fn greentic_operator_hook_api(&self) -> &Guest