StoreIndices

Struct StoreIndices 

pub struct StoreIndices {}
Auto-generated bindings for index of the exports of store.

This is an implementation detail of StorePre and can be constructed if needed as well.

For more information see Store as well.

Implementations

Source

impl StoreIndices

pub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<StoreIndices, Error>

Creates a new copy of StoreIndices bindings which can then be used to instantiate into a particular store.

This method may fail if the component does not have the required exports.

pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<Store, Error>

Uses the indices stored in self to load an instance of Store from the instance provided.

Note that at this time this method will additionally perform type-checks of all exports.