pub struct Logger {}Expand description
Auto-generated bindings for an instance a component which
implements the world logger.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
Logger::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
LoggerPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesLoggerPre::instantiateto create aLogger. -
If you’ve instantiated the instance yourself already then you can use
Logger::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl Logger
impl Logger
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Logger, Error>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<Logger, Error>
Convenience wrapper around LoggerPre::new and
LoggerPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<Logger, Error>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<Logger, Error>
Convenience wrapper around LoggerIndices::new and
LoggerIndices::load.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> <D as HasData>::Data<'_>,
) -> Result<(), Error>where
D: HostWithStore + HostWithStore,
<D as HasData>::Data<'a>: for<'a> Host + for<'a> Host,
T: 'static,